@@ -33,7 +33,9 @@ Event::Event(QObject* parent, const QString &name)
         : QObject(parent)
         , m_name(name)
         , m_hidden(false)
+        , m_notifierItem(0)
         , m_active(false)
+        , m_verbose(false)
 {
     m_hiddenCfgString = QString(QLatin1Literal("hide") % m_name % QLatin1Literal("Notifier"));
     m_hidden = readHiddenConfig();
@@ -64,6 +66,7 @@ void Event::readNotifyConfig()
     KConfig cfg("muon-notifierrc");
     KConfigGroup notifyTypeGroup(&cfg, "NotificationType");
     QString notifyType = notifyTypeGroup.readEntry("NotifyType", "Combo");
+    m_verbose = notifyTypeGroup.readEntry("Verbose", false);
 
     if (notifyType == "Combo") {
         m_useKNotify = true;
@@ -82,7 +85,7 @@ bool Event::isHidden() const
     return m_hidden;
 }
 
-void Event::show(const QString &icon, const QString &text, const QStringList &actions)
+void Event::show(const QString &icon, const QString &text, const QStringList &actions, const QString &tTipIcon)
 {
     if (m_active || m_hidden) {
         return;
@@ -100,7 +103,13 @@ void Event::show(const QString &icon, const QString &text, const QStringList &ac
         KNotification *notify = new KNotification(m_name, 0, flag);
         notify->setComponentData(KComponentData("muon-notifier"));
 
-        notify->setPixmap(KIcon(icon).pixmap(NOTIFICATION_ICON_SIZE));
+        KIcon notifyIcon(icon);
+
+        if (!tTipIcon.isEmpty()) {
+            notifyIcon = KIcon(tTipIcon);
+        }
+
+        notify->setPixmap(notifyIcon.pixmap(NOTIFICATION_ICON_SIZE));
         notify->setText(text);
 
         if (!m_useTrayIcon) {
@@ -119,7 +128,11 @@ void Event::show(const QString &icon, const QString &text, const QStringList &ac
         m_active = true;
         m_notifierItem = new KStatusNotifierItem(this);
         m_notifierItem->setIconByName(icon);
-        m_notifierItem->setToolTipIconByName(icon);
+        if (!tTipIcon.isEmpty()) {
+            m_notifierItem->setToolTipIconByName(tTipIcon);
+        } else {
+            m_notifierItem->setToolTipIconByName(icon);
+        }
         m_notifierItem->setToolTipTitle(i18n("System Notification"));
         m_notifierItem->setToolTipSubTitle(text);
         m_notifierItem->setStatus(KStatusNotifierItem::Active);
@@ -152,7 +165,7 @@ void Event::show(const QString &icon, const QString &text, const QStringList &ac
     }
 }
 
-void Event::update(const QString &icon, const QString &text)
+void Event::update(const QString &icon, const QString &text, const QString &tTipIcon)
 {
     if (!m_active) {
         return;
@@ -162,7 +175,11 @@ void Event::update(const QString &icon, const QString &text)
     // transient anyways.
     if (m_useTrayIcon && m_notifierItem) {
         m_notifierItem->setIconByName(icon);
-        m_notifierItem->setToolTipIconByName(icon);
+        if (!tTipIcon.isEmpty()) {
+            m_notifierItem->setToolTipIconByName(tTipIcon);
+        } else {
+            m_notifierItem->setToolTipIconByName(icon);
+        }
         m_notifierItem->setToolTipTitle(i18n("System Notification"));
         m_notifierItem->setToolTipSubTitle(text);
     }
@@ -197,6 +214,7 @@ void Event::notifyClosed()
 void Event::reloadConfig()
 {
     m_hidden = readHiddenConfig();
+    readNotifyConfig();
 }
 
 #include "event.moc"
