@@ -43,15 +43,15 @@
 #include <LibQApt/Config>
 
 // Own includes
-#include "config/ManagerSettingsDialog.h"
-#include "../libmuon/CommitWidget.h"
 #include "../libmuon/HistoryView/HistoryView.h"
-#include "../libmuon/DownloadWidget.h"
-#include "../libmuon/StatusWidget.h"
-#include "FilterWidget.h"
+#include "CommitWidget.h"
+#include "DownloadWidget.h"
+#include "FilterWidget/FilterWidget.h"
 #include "ManagerWidget.h"
 #include "ReviewWidget.h"
 #include "MuonSettings.h"
+#include "StatusWidget.h"
+#include "config/ManagerSettingsDialog.h"
 
 MainWindow::MainWindow()
     : MuonMainWindow()
@@ -88,6 +88,7 @@ void MainWindow::initGUI()
     m_managerWidget = new ManagerWidget(m_stack);
     connect(this, SIGNAL(backendReady(QApt::Backend *)),
             m_managerWidget, SLOT(setBackend(QApt::Backend *)));
+    connect(m_managerWidget, SIGNAL(packageChanged()), this, SLOT(setActionsEnabled()));
 
     m_mainWidget = new QSplitter(this);
     m_mainWidget->setOrientation(Qt::Horizontal);
