@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
+ *   Copyright © 2011 Jonathan Thomas <echidnaman@kubuntu.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -21,18 +21,53 @@
 #ifndef UPDATERWIDGET_H
 #define UPDATERWIDGET_H
 
-#include "../libmuon/PackageModel/PackageWidget.h"
+#include <QtGui/QWidget>
 
-class UpdaterWidget : public PackageWidget
+// LibQApt includes
+#include <LibQApt/Globals>
+#include <LibQApt/Package>
+
+class QItemSelection;
+class QStandardItemModel;
+class QTreeView;
+
+class KPixmapSequenceOverlayPainter;
+
+namespace QApt {
+    class Backend;
+}
+
+class Application;
+class UpdateModel;
+
+class UpdaterWidget : public QWidget
 {
     Q_OBJECT
 public:
-    UpdaterWidget(QWidget *parent);
-    ~UpdaterWidget();
+    explicit UpdaterWidget(QWidget *parent = 0);
+
+private:
+    QApt::Backend *m_backend;
+    QApt::CacheState m_oldCacheState;
+    UpdateModel *m_updateModel;
+    QList<Application *> m_upgradeableApps;
+
+    QTreeView *m_updateView;
+    KPixmapSequenceOverlayPainter *m_busyWidget;
 
 public Q_SLOTS:
     void setBackend(QApt::Backend *backend);
     void reload();
+
+private Q_SLOTS:
+    void populateUpdateModel();
+    void checkApps(QList<Application *> apps, bool checked);
+    void checkChanges(const QHash<QApt::Package::State, QApt::PackageList> &removals);
+    void selectionChanged(const QItemSelection &selected,
+                          const QItemSelection &deselected);
+
+signals:
+    void packageChanged(QApt::Package *Package);
 };
 
-#endif
+#endif // UPDATERWIDGET_H
